@@ -30,11 +30,9 @@ class TrainableComponent(Protocol):
         drop: float = 0.0,
         sgd: Optional[Optimizer] = None,
         losses: Optional[Dict[str, float]] = None
-    ) -> Dict[str, float]:
-        ...
+    ) -> Dict[str, float]: ...
 
-    def finish_update(self, sgd: Optimizer) -> None:
-        ...
+    def finish_update(self, sgd: Optimizer) -> None: ...
 
 
 @runtime_checkable
@@ -44,8 +42,7 @@ class InitializableComponent(Protocol):
         get_examples: Callable[[], Iterable["Example"]],
         nlp: "Language",
         **kwargs: Any
-    ):
-        ...
+    ): ...
 
 
 @runtime_checkable
@@ -55,11 +52,8 @@ class ListenedToComponent(Protocol):
     listener_map: Dict[str, Sequence[Model]]
     listening_components: List[str]
 
-    def add_listener(self, listener: Model, component_name: str) -> None:
-        ...
+    def add_listener(self, listener: Model, component_name: str) -> None: ...
 
-    def remove_listener(self, listener: Model, component_name: str) -> bool:
-        ...
+    def remove_listener(self, listener: Model, component_name: str) -> bool: ...
 
-    def find_listeners(self, component) -> None:
-        ...
+    def find_listeners(self, component) -> None: ...
